@@ -1,5 +1,5 @@
 package Bio::ToolBox::Data::Stream;
-our $VERSION = 1.24;
+our $VERSION = 1.26;
 
 =head1 NAME
 
@@ -539,8 +539,8 @@ sub new {
 		$data = generate_data_structure($feature, @datasets);
 		
 		# add file name information
-		my ($basename, $path, $extension) = parse_filename($filename);
-		$data->{filename}  = $filename;
+		my ($basename, $path, $extension) = parse_filename($args{filename});
+		$data->{filename}  = $args{filename};
 		$data->{basename}  = $basename;
 		$data->{path}      = $path;
 		$data->{extension} = $extension;
@@ -847,5 +847,4 @@ __END__
  Salt Lake City, UT, 84112
 
 This package is free software; you can redistribute it and/or modify
-it under the terms of the GPL (either version 1, or at your option,
-any later version) or the Artistic License 2.0.  
+it under the terms of the Artistic License 2.0.  
