@@ -11,9 +11,9 @@ use Bio::ToolBox::db_helper qw(
 	open_db_connection
 	verify_or_request_feature_types
 );
-use Bio::ToolBox::db_helper::gff3_parser;
+use Bio::ToolBox::gff3_parser;
 use Bio::ToolBox::utility;
-my $VERSION = 1.23;
+my $VERSION = 1.26;
 
 print "\n This program will get specific regions from features\n\n";
 
@@ -1443,5 +1443,4 @@ data collection.
  Salt Lake City, UT, 84112
 
 This package is free software; you can redistribute it and/or modify
-it under the terms of the GPL (either version 1, or at your option,
-any later version) or the Artistic License 2.0.  
+it under the terms of the Artistic License 2.0.  
