@@ -5,12 +5,12 @@
 use strict;
 use Getopt::Long;
 use Pod::Usage;
-use Bio::ToolBox::db_helper::gff3_parser;
+use Bio::ToolBox::gff3_parser;
 use Bio::ToolBox::file_helper qw(
 	open_to_write_fh
 );
 
-my $VERSION = '1.21';
+my $VERSION = 1.26;
 
 
 print "\n This program will convert a GFF3 file to UCSC gene table\n";
@@ -870,5 +870,4 @@ program available at L<http://hgdownload.cse.ucsc.edu/admin/exe/>.
  Salt Lake City, UT, 84112
 
 This package is free software; you can redistribute it and/or modify
-it under the terms of the GPL (either version 1, or at your option,
-any later version) or the Artistic License 2.0.  
+it under the terms of the Artistic License 2.0.  
